======
autonl
======

.. image:: https://img.shields.io/pypi/v/autonl.svg
    :target: https://pypi.org/project/autonl/
    :alt: PyPI Version

.. image:: https://github.com/yukihira1992/autonl/workflows/Test%20package/badge.svg
    :target: https://github.com/yukihira1992/autonl/actions
    :alt: Build status


autonl automatically formats newline at end of file.


Installation
============

Installing from PyPI::

    pip install --upgrade autonl


Usage
=====

Formatting newline at end of file::

    autonl <filename>
